@@ -45,14 +45,14 @@ if(argc==2) fontdesc=argv[1];
  */
 printf("#ifndef DEFINED_STRUCT_FONTINFO_TAG\n");
 printf("#define DEFINED_STRUCT_FONTINFO_TAG 1\n");
-printf("\
-struct fontinfo_tag
-  {
-  signed char *data;
-  int table[96];
-  int yofs,fh,oy;
-  };
-");
+printf(
+"struct fontinfo_tag\n"
+"  {\n"
+"  signed char *data;\n"
+"  int table[96];\n"
+"  int yofs,fh,oy;\n"
+"  };\n"
+);
 printf("#endif\n\n");
 
 /* generate font data */
