@@ -13,7 +13,7 @@
  
 #include <stdio.h>
 #include <string.h>
-#include <vga.h>
+#include "zgv_io.h"
 #include "zgv.h"
 #include "font.h"
 #include "fontbmps.h"
@@ -68,10 +68,10 @@ printf(bitmap_fonts_copyright);
 
 
 /* needed for 360x480 mode */
-#define vga_drawline(x1,y1,x2,y2) \
+#define alt_vga_drawline(x1,y1,x2,y2) \
 	(squish_x?vga_drawline((x1)>>1,y1,(x2)>>1,y2):\
         	  vga_drawline(x1,y1,x2,y2))
-#define vga_drawpixel(x1,y1) \
+#define alt_vga_drawpixel(x1,y1) \
 	(squish_x?vga_drawpixel((x1)>>1,y1):\
         	  vga_drawpixel(x1,y1))
 
@@ -133,7 +133,7 @@ for(f=0;f<strlen(str);f++)
         fontc_lr(a+s1,b+s3,siz);
       /* common line */
       if(strchr("BDEFHKLMNPR",c)!=NULL)
-        vga_drawline(a,b,a,b+s4);
+        alt_vga_drawline(a,b,a,b+s4);
       }
     }
 
@@ -144,179 +144,179 @@ for(f=0;f<strlen(str);f++)
     switch(c)
       {
       case 'a':
-        vga_drawline(a+s2,b+s2,a+s2,b+s4); break;
+        alt_vga_drawline(a+s2,b+s2,a+s2,b+s4); break;
       case 'b':
-        vga_drawline(a,b,a,b+s4); break;
+        alt_vga_drawline(a,b,a,b+s4); break;
       case 'c':
-        vga_drawline(a+s1,b+s2,a+s2,b+s2);
-        vga_drawline(a+s1,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a+s1,b+s2,a+s2,b+s2);
+        alt_vga_drawline(a+s1,b+s4,a+s2,b+s4); break;
       case 'd':
-        vga_drawline(a+s2,b,a+s2,b+s4); break;
+        alt_vga_drawline(a+s2,b,a+s2,b+s4); break;
       case 'e':
-        vga_drawline(a,b+s3,a+s2,b+s3);
-        vga_drawline(a+s1,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b+s3,a+s2,b+s3);
+        alt_vga_drawline(a+s1,b+s4,a+s2,b+s4); break;
       case 'f':
-        fontc_ul(a+s1,b+s1,siz); vga_drawline(a,b+s1,a,b+s4);
-        vga_drawline(a,b+s2,a+s1,b+s2); break;
+        fontc_ul(a+s1,b+s1,siz); alt_vga_drawline(a,b+s1,a,b+s4);
+        alt_vga_drawline(a,b+s2,a+s1,b+s2); break;
       case 'g':
-        vga_drawline(a+s2,b+s2,a+s2,b+s5);
+        alt_vga_drawline(a+s2,b+s2,a+s2,b+s5);
         fontc_l(a+s1,b+s5,siz); break;
       case 'h':
-        vga_drawline(a,b,a,b+s4); vga_drawline(a+s2,b+s3,a+s2,b+s4); break;
+        alt_vga_drawline(a,b,a,b+s4); alt_vga_drawline(a+s2,b+s3,a+s2,b+s4); break;
       case 'i':
-        vga_drawpixel(a,b+s1);
-        vga_drawline(a,b+s2,a,b+s4);
+        alt_vga_drawpixel(a,b+s1);
+        alt_vga_drawline(a,b+s2,a,b+s4);
         a+=-s1+1; break;
       case 'j':
-        vga_drawline(a+s1,b+s2,a+s1,b+s5);
+        alt_vga_drawline(a+s1,b+s2,a+s1,b+s5);
         fontc_lr(a,b+s5,siz);
-        vga_drawpixel(a+s1,b+s1); break;
+        alt_vga_drawpixel(a+s1,b+s1); break;
       case 'k':
-        vga_drawline(a,b,a,b+s4); vga_drawline(a,b+s3,a+s1,b+s2);
-        vga_drawline(a,b+s3,a+s1,b+s4); break;
+        alt_vga_drawline(a,b,a,b+s4); alt_vga_drawline(a,b+s3,a+s1,b+s2);
+        alt_vga_drawline(a,b+s3,a+s1,b+s4); break;
       case 'l':
-        vga_drawline(a,b,a,b+s3); break;
+        alt_vga_drawline(a,b,a,b+s3); break;
       case 'm':
-        vga_drawline(a,b+s2,a,b+s4); vga_drawline(a+s2,b+s3,a+s2,b+s4);
-        vga_drawline(a+s4,b+s3,a+s4,b+s4); fontc_u(a+s3,b+s3,siz);
+        alt_vga_drawline(a,b+s2,a,b+s4); alt_vga_drawline(a+s2,b+s3,a+s2,b+s4);
+        alt_vga_drawline(a+s4,b+s3,a+s4,b+s4); fontc_u(a+s3,b+s3,siz);
         break;
       case 'n':
-        vga_drawline(a,b+s2,a,b+s4); vga_drawline(a+s2,b+s3,a+s2,b+s4);
+        alt_vga_drawline(a,b+s2,a,b+s4); alt_vga_drawline(a+s2,b+s3,a+s2,b+s4);
         break;
       case 'p':
-        vga_drawline(a,b+s2,a,b+s6); break;
+        alt_vga_drawline(a,b+s2,a,b+s6); break;
       case 'q':
-        vga_drawline(a+s2,b+s2,a+s2,b+s6); break;
+        alt_vga_drawline(a+s2,b+s2,a+s2,b+s6); break;
       case 'r':
-        vga_drawline(a,b+s2,a,b+s4); break;
+        alt_vga_drawline(a,b+s2,a,b+s4); break;
       case 's':
-        vga_drawline(a,b+s3,a+s2,b+s3); vga_drawline(a+s1,b+s2,a+s2,b+s2);
-        vga_drawline(a,b+s4,a+s1,b+s4);
+        alt_vga_drawline(a,b+s3,a+s2,b+s3); alt_vga_drawline(a+s1,b+s2,a+s2,b+s2);
+        alt_vga_drawline(a,b+s4,a+s1,b+s4);
         break;
       case 't':
-        vga_drawline(a,b+s1,a,b+s3); vga_drawline(a,b+s2,a+s1,b+s2);
+        alt_vga_drawline(a,b+s1,a,b+s3); alt_vga_drawline(a,b+s2,a+s1,b+s2);
         break;
       case 'u':
-        vga_drawline(a,b+s2,a,b+s3); vga_drawline(a+s2,b+s2,a+s2,b+s4);
+        alt_vga_drawline(a,b+s2,a,b+s3); alt_vga_drawline(a+s2,b+s2,a+s2,b+s4);
         break;
       case 'v':
-        vga_drawline(a,b+s2,a+s1,b+s4); vga_drawline(a+s1,b+s4,a+s2,b+s2);
+        alt_vga_drawline(a,b+s2,a+s1,b+s4); alt_vga_drawline(a+s1,b+s4,a+s2,b+s2);
         break;
       case 'w':
-        vga_drawline(a,b+s2,a+s1,b+s4); vga_drawline(a+s1,b+s4,a+s2,b+s3);
-        vga_drawline(a+s2,b+s3,a+s3,b+s4); vga_drawline(a+s3,b+s4,a+s4,b+s2);
+        alt_vga_drawline(a,b+s2,a+s1,b+s4); alt_vga_drawline(a+s1,b+s4,a+s2,b+s3);
+        alt_vga_drawline(a+s2,b+s3,a+s3,b+s4); alt_vga_drawline(a+s3,b+s4,a+s4,b+s2);
         break;
       case 'x':
-        vga_drawline(a,b+s2,a+s2,b+s4); vga_drawline(a,b+s4,a+s2,b+s2);
+        alt_vga_drawline(a,b+s2,a+s2,b+s4); alt_vga_drawline(a,b+s4,a+s2,b+s2);
         break;
       case 'y':
-        vga_drawline(a,b+s2,a,b+s3);
-        vga_drawline(a+s2,b+s2,a+s2,b+s5);
+        alt_vga_drawline(a,b+s2,a,b+s3);
+        alt_vga_drawline(a+s2,b+s2,a+s2,b+s5);
         fontc_l(a+s1,b+s5,siz); break;
       case 'z':
-        vga_drawline(a,b+s2,a+s2,b+s2); vga_drawline(a+s2,b+s2,a,b+s4);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b+s2,a+s2,b+s2); alt_vga_drawline(a+s2,b+s2,a,b+s4);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       
       /*** 2b: uppercase letters ***/
   
       case 'A':
-        vga_drawline(a,b+s4,a+s1,b); vga_drawline(a+s1,b,a+s2,b+s4);
-        vga_drawline(a+(s1>>1),b+s2,a+s2-(s1>>1),b+s2); break;
+        alt_vga_drawline(a,b+s4,a+s1,b); alt_vga_drawline(a+s1,b,a+s2,b+s4);
+        alt_vga_drawline(a+(s1>>1),b+s2,a+s2-(s1>>1),b+s2); break;
       case 'B':
         fontc_r(a+s1,b+s1,siz);
-        vga_drawline(a,b,a+s1,b); vga_drawline(a,b+s2,a+s1,b+s2);
-        vga_drawline(a,b+s4,a+s1,b+s4); break;
+        alt_vga_drawline(a,b,a+s1,b); alt_vga_drawline(a,b+s2,a+s1,b+s2);
+        alt_vga_drawline(a,b+s4,a+s1,b+s4); break;
       case 'C':
-        fontc_u(a+s1,b+s1,siz); vga_drawline(a,b+s1,a,b+s3);
+        fontc_u(a+s1,b+s1,siz); alt_vga_drawline(a,b+s1,a,b+s3);
         break;
       case 'D':
-        vga_drawline(a,b,a+s1,b);
-        vga_drawline(a,b+s4,a+s1,b+s4); fontc_ur(a+s1,b+s1,siz);
-        vga_drawline(a+s2,b+s1,a+s2,b+s3); break;
+        alt_vga_drawline(a,b,a+s1,b);
+        alt_vga_drawline(a,b+s4,a+s1,b+s4); fontc_ur(a+s1,b+s1,siz);
+        alt_vga_drawline(a+s2,b+s1,a+s2,b+s3); break;
       case 'E':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a,b+s2,a+s1,b+s2);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a,b+s2,a+s1,b+s2);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       case 'F':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a,b+s2,a+s1,b+s2);
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a,b+s2,a+s1,b+s2);
         break;
       case 'G':
-        fontc_u(a+s1,b+s1,siz); vga_drawline(a,b+s1,a,b+s3);
-        vga_drawline(a+s1,b+s2,a+s2,b+s2); vga_drawline(a+s2,b+s2,a+s2,b+s3);
+        fontc_u(a+s1,b+s1,siz); alt_vga_drawline(a,b+s1,a,b+s3);
+        alt_vga_drawline(a+s1,b+s2,a+s2,b+s2); alt_vga_drawline(a+s2,b+s2,a+s2,b+s3);
         break;
       case 'H':
-        vga_drawline(a,b+s2,a+s2,b+s2); vga_drawline(a+s2,b,a+s2,b+s4);
+        alt_vga_drawline(a,b+s2,a+s2,b+s2); alt_vga_drawline(a+s2,b,a+s2,b+s4);
         break;
       case 'I':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a+s1,b,a+s1,b+s4);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a+s1,b,a+s1,b+s4);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       case 'J':
-        vga_drawline(a+s2,b,a+s2,b+s3); break;
+        alt_vga_drawline(a+s2,b,a+s2,b+s3); break;
       case 'K':
-        vga_drawline(a+s2,b,a,b+s2); vga_drawline(a,b+s2,a+s2,b+s4); break;
+        alt_vga_drawline(a+s2,b,a,b+s2); alt_vga_drawline(a,b+s2,a+s2,b+s4); break;
       case 'L':
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       case 'M':
-        vga_drawline(a,b,a+s1+(s1>>1),b+s2);
-        vga_drawline(a+s1+(s1>>1),b+s2,a+s3,b);
-        vga_drawline(a+s3,b,a+s3,b+s4); a-=s1; break;
+        alt_vga_drawline(a,b,a+s1+(s1>>1),b+s2);
+        alt_vga_drawline(a+s1+(s1>>1),b+s2,a+s3,b);
+        alt_vga_drawline(a+s3,b,a+s3,b+s4); a-=s1; break;
       case 'N':
-        vga_drawline(a,b,a+s2,b+s4); vga_drawline(a+s2,b+s4,a+s2,b); break;
+        alt_vga_drawline(a,b,a+s2,b+s4); alt_vga_drawline(a+s2,b+s4,a+s2,b); break;
       case 'Q':
-        vga_drawline(a+s1,b+s3,a+s2,b+s4);
+        alt_vga_drawline(a+s1,b+s3,a+s2,b+s4);
         /* FALLS THROUGH and adds an O, finishing the Q */ 
       case 'O': case '0':   /* all other numbers done later */
-        fontc_u(a+s1,b+s1,siz); vga_drawline(a,b+s1,a,b+s3);
-        vga_drawline(a+s2,b+s1,a+s2,b+s3); break;
+        fontc_u(a+s1,b+s1,siz); alt_vga_drawline(a,b+s1,a,b+s3);
+        alt_vga_drawline(a+s2,b+s1,a+s2,b+s3); break;
       case 'R':
-        vga_drawline(a+s1,b+s2,a+s2,b+s4);
+        alt_vga_drawline(a+s1,b+s2,a+s2,b+s4);
         /* FALLS THROUGH and adds a P, finishing the R */
       case 'P':
-        fontc_r(a+s1,b+s1,siz); vga_drawline(a,b,a+s1,b);
-        vga_drawline(a,b+s2,a+s1,b+s2); break;
+        fontc_r(a+s1,b+s1,siz); alt_vga_drawline(a,b,a+s1,b);
+        alt_vga_drawline(a,b+s2,a+s1,b+s2); break;
       case 'S':
         fontc_left(a+s1,b+s1,siz); fontc_ur(a+s1,b+s1,siz); break;
       case 'T':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a+s1,b,a+s1,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a+s1,b,a+s1,b+s4); break;
       case 'U':
-        vga_drawline(a,b,a,b+s3); vga_drawline(a+s2,b,a+s2,b+s3); break;
+        alt_vga_drawline(a,b,a,b+s3); alt_vga_drawline(a+s2,b,a+s2,b+s3); break;
       case 'V':
-        vga_drawline(a,b,a+s1,b+s4); vga_drawline(a+s1,b+s4,a+s2,b); break;
+        alt_vga_drawline(a,b,a+s1,b+s4); alt_vga_drawline(a+s1,b+s4,a+s2,b); break;
       case 'W':
-        vga_drawline(a,b,a+s1,b+s4); vga_drawline(a+s1,b+s4,a+s2,b+s2);
-        vga_drawline(a+s2,b+s2,a+s3,b+s4); vga_drawline(a+s3,b+s4,a+s4,b);
+        alt_vga_drawline(a,b,a+s1,b+s4); alt_vga_drawline(a+s1,b+s4,a+s2,b+s2);
+        alt_vga_drawline(a+s2,b+s2,a+s3,b+s4); alt_vga_drawline(a+s3,b+s4,a+s4,b);
         break;
       case 'X':
-        vga_drawline(a,b,a+s2,b+s4); vga_drawline(a+s2,b,a,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b+s4); alt_vga_drawline(a+s2,b,a,b+s4); break;
       case 'Y':
-        vga_drawline(a,b,a+s1,b+s2); vga_drawline(a+s2,b,a+s1,b+s2);
-        vga_drawline(a+s1,b+s2,a+s1,b+s4); break;
+        alt_vga_drawline(a,b,a+s1,b+s2); alt_vga_drawline(a+s2,b,a+s1,b+s2);
+        alt_vga_drawline(a+s1,b+s2,a+s1,b+s4); break;
       case 'Z':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a+s2,b,a,b+s4);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a+s2,b,a,b+s4);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       
       /*** 2c: numbers ***/
     
       /* 0 already done */
       case '1':
-        vga_drawline(a,b+s1,a+s1,b); vga_drawline(a+s1,b,a+s1,b+s4);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        alt_vga_drawline(a,b+s1,a+s1,b); alt_vga_drawline(a+s1,b,a+s1,b+s4);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       case '2':
-        fontc_u(a+s1,b+s1,siz); vga_drawline(a+s2,b+s1,a,b+s4);
-        vga_drawline(a,b+s4,a+s2,b+s4); break;
+        fontc_u(a+s1,b+s1,siz); alt_vga_drawline(a+s2,b+s1,a,b+s4);
+        alt_vga_drawline(a,b+s4,a+s2,b+s4); break;
       case '3':
         fontc_u(a+s1,b+s1,siz); fontc_lr(a+s1,b+s1,siz); break;
       case '4':
-        vga_drawline(a+s1,b+s4,a+s1,b); vga_drawline(a+s1,b,a,b+s2);
-        vga_drawline(a,b+s2,a+s2,b+s2); break;
+        alt_vga_drawline(a+s1,b+s4,a+s1,b); alt_vga_drawline(a+s1,b,a,b+s2);
+        alt_vga_drawline(a,b+s2,a+s2,b+s2); break;
       case '5':
-        vga_drawline(a+s2,b,a,b); vga_drawline(a,b,a,b+s2);
-        vga_drawline(a,b+s2,a+s1,b+s2); break;
+        alt_vga_drawline(a+s2,b,a,b); alt_vga_drawline(a,b,a,b+s2);
+        alt_vga_drawline(a,b+s2,a+s1,b+s2); break;
       case '6':
-        fontc_u(a+s1,b+s1,siz); vga_drawline(a,b+s1,a,b+s3); break;
+        fontc_u(a+s1,b+s1,siz); alt_vga_drawline(a,b+s1,a,b+s3); break;
       case '7':
-        vga_drawline(a,b,a+s2,b); vga_drawline(a+s2,b,a+s1,b+s4); break;
+        alt_vga_drawline(a,b,a+s2,b); alt_vga_drawline(a+s2,b,a+s1,b+s4); break;
       case '9':
-        vga_drawline(a+s2,b,a+s2,b+s4);
+        alt_vga_drawline(a+s2,b,a+s2,b+s4);
         /* FALLS THROUGH and does top circle of 8 to complete the 9 */
       case '8':
         fontcircle(a+s1,b+s1,siz); break;
@@ -324,26 +324,26 @@ for(f=0;f<strlen(str);f++)
       /* 2d: some punctuation (not much!) */
       
       case '-':
-        vga_drawline(a,b+s2,a+s1,b+s2); break;
+        alt_vga_drawline(a,b+s2,a+s1,b+s2); break;
       case '.':
-        vga_drawpixel(a,b+s4); a+=-s1+1; break;
+        alt_vga_drawpixel(a,b+s4); a+=-s1+1; break;
       case '(':
         fontc_ul(a+s1,b+s1,siz); fontc_ll(a+s1,b+s3,siz);
-        vga_drawline(a,b+s1,a,b+s3); break;
+        alt_vga_drawline(a,b+s1,a,b+s3); break;
       case ')':
         fontc_ur(a,b+s1,siz); fontc_lr(a,b+s3,siz);
-        vga_drawline(a+s1,b+s1,a+s1,b+s3); break;
+        alt_vga_drawline(a+s1,b+s1,a+s1,b+s3); break;
       case '%':
-        vga_drawpixel(a,b);
-        vga_drawpixel(a+s2,b+s4);
+        alt_vga_drawpixel(a,b);
+        alt_vga_drawpixel(a+s2,b+s4);
         /* FALLS THROUGH drawing the slash to finish the % */
       case '/':
-        vga_drawline(a,b+s4,a+s2,b); break;
+        alt_vga_drawline(a,b+s4,a+s2,b); break;
       case '?':
         fontc_u(a+s1,b+s1,siz);
-        vga_drawline(a+s2,b+s1,a+s1,b+s2);
-        vga_drawline(a+s1,b+s2,a+s1,b+s3);
-        vga_drawpixel(a+s1,b+s4);
+        alt_vga_drawline(a+s2,b+s1,a+s1,b+s2);
+        alt_vga_drawline(a+s1,b+s2,a+s1,b+s3);
+        alt_vga_drawpixel(a+s1,b+s4);
         break;
       }
 
@@ -373,7 +373,7 @@ for(f=0;f<strlen(str);f++)
           /* oh, don't know this one. do an underscore */
           /* (we don't if go_through_the_motions is set) */
           if(!go_through_the_motions)
-            vga_drawline(a,b+s4,a+s2,b+s4);
+            alt_vga_drawline(a,b+s4,a+s2,b+s4);
           a+=s2;
           }
         }
@@ -423,8 +423,8 @@ int r34;
 
 if(go_through_the_motions) return;
 r34=((r*3)>>2);
-vga_drawline(x-r,y,x-r34,y-r34);
-vga_drawline(x-r34,y-r34,x,y-r);
+alt_vga_drawline(x-r,y,x-r34,y-r34);
+alt_vga_drawline(x-r34,y-r34,x,y-r);
 }
 
 void fontc_ur(int x,int y,int r)
@@ -433,8 +433,8 @@ int r34;
 
 if(go_through_the_motions) return;
 r34=((r*3)>>2);
-vga_drawline(x+r,y,x+r34,y-r34);
-vga_drawline(x+r34,y-r34,x,y-r);
+alt_vga_drawline(x+r,y,x+r34,y-r34);
+alt_vga_drawline(x+r34,y-r34,x,y-r);
 }
 
 void fontc_ll(int x,int y,int r)
@@ -443,8 +443,8 @@ int r34;
 
 if(go_through_the_motions) return;
 r34=((r*3)>>2);
-vga_drawline(x-r,y,x-r34,y+r34);
-vga_drawline(x-r34,y+r34,x,y+r);
+alt_vga_drawline(x-r,y,x-r34,y+r34);
+alt_vga_drawline(x-r34,y+r34,x,y+r);
 }
 
 void fontc_lr(int x,int y,int r)
@@ -453,16 +453,11 @@ int r34;
 
 if(go_through_the_motions) return;
 r34=((r*3)>>2);
-vga_drawline(x+r,y,x+r34,y+r34);
-vga_drawline(x+r34,y+r34,x,y+r);
+alt_vga_drawline(x+r,y,x+r34,y+r34);
+alt_vga_drawline(x+r34,y+r34,x,y+r);
 }
 
 
-/* lose 360x480 junk */
-#undef vga_drawline
-#undef vga_drawpixel
-
-
 /* this gets how wide text will be */
 int vgatextsize(int sizearg,char *str)
 {
