@@ -4,4 +4,4 @@
  * helppage.h - prototype for showhelp() from helppage.c.
  */
 
-extern int showhelp(int ttyfd,char *title,char *help[]);
+extern void showhelp(int ttyfd,char *title,char *help[]);
