@@ -1,5 +1,5 @@
-/* Zgv v3.0 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-1998 Russell Marks. See README for license details.
+/* zgv 5.3 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2001 Russell Marks. See README for license details.
  *
  * magic.h
  */
@@ -16,6 +16,9 @@
 #define _IS_XBM			10
 #define _IS_XPM			11
 #define _IS_TIFF		12
+#define _IS_PCD			13
+#define _IS_PRF			14
+
 #define _IS_BAD		 	99
 
 extern int magic_ident(char *filename);
