@@ -1,12 +1,12 @@
-/* zgv 5.4 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-2001 Russell Marks. See README for license details.
+/* zgv 5.6 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2002 Russell Marks. See README for license details.
  *
  * modesel.c - mode-selection array (and check routine for it).
  *		To add a video mode to zgv, just add an entry here.
  */
 
 #include <stdio.h>
-#include <vga.h>
+#include "zgv_io.h"
 #include "readnbkey.h"
 #include "modesel.h"
 
@@ -37,6 +37,7 @@ struct modedesc_tag modedesc[]=
   
   /* SVGA 15-bit modes */
   { G320x200x32K,	320,200,15,2,	RK_NO_KEY,	0,RK_F5 },
+  { G320x240x32K,	320,240,15,2,	RK_NO_KEY,	0,RK_NO_KEY },
   { G640x480x32K,	640,480,15,2,	RK_NO_KEY,	0,RK_F8 },
   { G800x600x32K,	800,600,15,2,	RK_NO_KEY,	0,RK_SHIFT_F1 },
   { G1024x768x32K,	1024,768,15,2,	RK_NO_KEY,	0,RK_SHIFT_F4 },
@@ -46,6 +47,7 @@ struct modedesc_tag modedesc[]=
   
   /* SVGA 16-bit modes */
   { G320x200x64K,	320,200,16,2,	RK_NO_KEY,	0,RK_F6 },
+  { G320x240x64K,	320,240,16,2,	RK_NO_KEY,	0,RK_NO_KEY },
   { G640x480x64K,	640,480,16,2,	RK_NO_KEY,	0,RK_F9 },
   { G800x600x64K,	800,600,16,2,	RK_NO_KEY,	0,RK_SHIFT_F2 },
   { G1024x768x64K,	1024,768,16,2,	RK_NO_KEY,	0,RK_SHIFT_F5 },
@@ -61,6 +63,7 @@ struct modedesc_tag modedesc[]=
    * variants.
    */
   { G320x200x16M32,	320,200,24,4,	RK_NO_KEY,	0,RK_F7 },
+  { G320x240x16M32,	320,240,24,4,	RK_NO_KEY,	0,'^' },
   { G640x480x16M32,	640,480,24,4,	RK_NO_KEY,	0,RK_F10 },
   { G800x600x16M32,	800,600,24,4,	RK_NO_KEY,	0,RK_SHIFT_F3 },
   { G1024x768x16M32,	1024,768,24,4,	RK_NO_KEY,	0,RK_SHIFT_F6 },
@@ -75,6 +78,7 @@ struct modedesc_tag modedesc[]=
    * I welcome feedback on whether this is the Right Thing or not.)
    */
   { G320x200x16M,	320,200,24,3,	RK_NO_KEY,	0,RK_F7 },
+  { G320x240x16M,	320,240,24,3,	RK_NO_KEY,	0,'^' },
   { G640x480x16M,	640,480,24,3,	RK_NO_KEY,	0,RK_F10 },
   { G800x600x16M,	800,600,24,3,	RK_NO_KEY,	0,RK_SHIFT_F3 },
   { G1024x768x16M,	1024,768,24,3,	RK_NO_KEY,	0,RK_SHIFT_F6 },
@@ -181,14 +185,15 @@ for(ptr=modedesc;ptr->mode;ptr++)
 
 /* check keys are 5..9 or RK_F1..RK_F10 or RK_SHIFT_F1..RK_SHIFT_F8
  * (only up to shift-F8 as only `F1'..`F20' seem to reliably generate
- * known strings) or 0.
+ * known strings) or 0 or ^.
  */
 #define TEST_KEY(x) \
   if(x!=RK_NO_KEY && \
      (x<'5' || x>'9') && \
      (x<RK_F1 || x>RK_F10) && \
      (x<RK_SHIFT_F1 || x>RK_SHIFT_F8) && \
-     (x!='0')) \
+     (x!='0') && \
+     (x!='^')) \
     cma_abort(ptr,"key not a permitted mode-selecting key")
 
 for(ptr=modedesc;ptr->mode;ptr++)
