@@ -7,8 +7,7 @@
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <vga.h>
-#include <vgagl.h>
+#include "zgv_io.h"
 #include "3deffects.h"
 #include "font.h"
 #include "rc_config.h"
