@@ -17,8 +17,6 @@ struct rbm_data_tag
 #define RBM_RIGHT_XSKIP		RBM_LEFT_XSKIP
 #define RBM_TOP_YSKIP		8
 #define RBM_BOT_YSKIP		RBM_TOP_YSKIP
-#define RBM_TEXT_XSKIP		5
-#define RBM_TEXT_YSKIP		5
 
 /* could have variable vertical size easily enough, but I thought
  * keeping the arrangement of buttons the same in all modes would be best.
@@ -36,7 +34,13 @@ struct rbm_data_tag
 
 extern void rbm_xysize(struct rbm_data_tag menu_data[],int *wp,int *hp);
 extern void rbm_draw(struct rbm_data_tag menu_data[],
-		int light,int medium,int dark,int black);
+                     int light,int medium,int dark,int black);
 extern int rbm_mousepos_to_key(struct rbm_data_tag menu_data[],int mx,int my);
 extern void rbm_set_active_flag(struct rbm_data_tag menu_data[],
-		char *substr,int active);
+                                char *substr,int active);
+extern void rbm_find_and_fix_ui_cols(int *lightp,int *mediump,
+                                     int *darkp,int *blackp,
+                                     int *mblackp,
+                                     unsigned char *palr64,
+                                     unsigned char *palg64,
+                                     unsigned char *palb64);
