@@ -1,5 +1,5 @@
-/* zgv 5.2 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-2000 Russell Marks. See README for license details.
+/* zgv 5.8 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2004 Russell Marks. See README for license details.
  *
  * rc_config.h - Defined! the zgv_config structure.
  *                       photographic evidence on page 2. :-)
@@ -42,6 +42,8 @@ struct zgv_config
   int fsmagic;
   int black_bg;
   int auto_animate;
+  int fullscreen;
+  int dither_hicol;
   
   int brightness;
   double contrast;
