@@ -177,7 +177,8 @@ int read_bmp_file (char *filename, hffunc howfarfunc, unsigned char **bmap,
   bytepp=1;
   if ((pp->bpp == 24) && (*output_type == 3))
     bytepp = 3;
-  if ((work_bmap = *bmap = calloc (w * (h + 2) * bytepp,1)) == NULL)
+  if (WH_BAD(w,h) ||
+      (work_bmap = *bmap = calloc (w * (h + 2) * bytepp,1)) == NULL)
     CLOSE_AND_RET(_PICERR_NOMEM);
 
   bytes_in_image=w*h*bytepp;
