@@ -15,7 +15,13 @@
 /* XXX should make this allocate on the fly rather than inflicting
  * arbitrary values on people... :-)
  */
-#define MAX_GIF_IMAGES	256
+#define MAX_GIF_IMAGES		256
+
+/* this only enforced for multi-image GIFs. Leaves room for GIFs to
+ * be loaded as 24-bit at some point in the future, though they're
+ * always 8-bit as things are.
+ */
+#define MAX_GIFMULTI_BYTES_PER_IMAGE	((1<<22)-1)
 
 
 static byte *image;
@@ -212,7 +218,7 @@ while(c=='!')      /* oh damn it, they've put an ext. block in, ditch it */
     
     default:	/* other block types are ignored */
       c=fgetc(in);
-      while(c)
+      while(c && c!=EOF)
         {    /* well then, c = number of bytes, so ignore that many */
         for(f=0;f<c;f++) fgetc(in);
         c=fgetc(in);
@@ -469,6 +475,7 @@ while((poserr=readimagehed(in))==_PIC_OK)
   
   images[imagecount++]=im;
   
+  im->image=NULL;
   im->cmap=NULL;
   im->width=width;
   im->height=height;
@@ -491,7 +498,7 @@ while((poserr=readimagehed(in))==_PIC_OK)
     readcolmap(in,im->cmap,lnumcols);
     }
   
-  if((im->image=(byte *)malloc(width*height))==NULL)
+  if(WH_BAD(width,height) || (im->image=(byte *)malloc(width*height))==NULL)
     {
     fclose(in);
     return(_PICERR_NOMEM);
@@ -599,6 +606,16 @@ else
 
 /* allocate main image and palette */
 
+/* width/height already checked in read_gif_multi(), here we
+ * check the number of images and their size won't cause a problem.
+ */
+if(imagecount>1 && (imagecount>MAX_GIF_IMAGES ||
+                    swidth*sheight>MAX_GIFMULTI_BYTES_PER_IMAGE))
+  {
+  images_cleanup();
+  return(_PICERR_NOMEM);
+  }
+
 if((*theimageptr=(byte *)malloc(ginfo->width*ginfo->height))==NULL)
   {
   images_cleanup();
@@ -668,7 +685,11 @@ else	/* if more than one image... */
   for(i=0;i<imagecount;i++)
     {
     int x,y,left,w;
-    unsigned char *ptr1,*ptr2;
+    unsigned char *ptr1,*ptr2,*oldptr1;
+
+    /* basic width/height vs. "screen" checks, left/top handled elsewhere */
+    if(images[i]->width>swidth) images[i]->width=swidth;
+    if(images[i]->height>sheight) images[i]->height=sheight;
     
     /* for images after the first, we need to set the initial contents
      * (as far as GIF is concerned, the `screen' contents) as directed
@@ -708,20 +729,28 @@ else	/* if more than one image... */
          */
         }
       }
-    
-    ptr1=ptr+images[i]->left+images[i]->top*swidth;
-    ptr2=images[i]->image;
-    
-    for(y=0;y<images[i]->height;y++)
+
+    /* an image with left or top offscreen is broken, but relying
+     * unknowingly on the image not appearing at all. So skip it.
+     */
+    if(images[i]->left<swidth && images[i]->top<sheight)
       {
-      for(x=0;x<images[i]->width;x++)
-        if(!(images[i]->gcb_control&1) ||   /* if no transparent col defined */
-             images[i]->transparent_col!=*ptr2)
-          *ptr1++=*ptr2++;
-        else
-          ptr1++,ptr2++;
+      ptr1=ptr+images[i]->left+images[i]->top*swidth;
       
-      ptr1+=swidth-images[i]->width;
+      for(y=0;y<images[i]->height && images[i]->top+y<sheight;y++)
+        {
+        oldptr1=ptr1;
+        ptr2=images[i]->image+y*images[i]->width;
+        
+        for(x=0;x<images[i]->width && images[i]->left+x<swidth;x++)
+          if(!(images[i]->gcb_control&1) || /* if no transparent col defined */
+               images[i]->transparent_col!=*ptr2)
+            *ptr1++=*ptr2++;
+          else
+            ptr1++,ptr2++;
+
+        ptr1=oldptr1+swidth;
+        }
       }
     
     ptr+=swidth*sheight;
