@@ -190,10 +190,10 @@ if(quick)
   height=cinfo.output_height;
   }
 
-theimage=(byte *)malloc(pixelsize*width*height);
-if(theimage==NULL)
+if(WH_BAD(width,height) ||
+   (theimage=(byte *)malloc(pixelsize*width*height))==NULL)
   {
-  jpegerr("Out of memory");
+  jpegerr("Out of memory");	/* XXX misleading if width/height are bad */
   longjmp(jerr.setjmp_buffer,1);
   }
 
