@@ -144,7 +144,7 @@ if(sub==2 && cfg.betterpgm && cfg.jpeg24bit && (*output_type)==3)
  * 3 times as much for each line, which works out only meaning
  * 3x as much for the last line. If you see what I mean. (!?)
  */
-if((*bmap=malloc(w*(h+2)*bytepp))==NULL)
+if(WH_BAD(w,h) || (*bmap=malloc(w*(h+2)*bytepp))==NULL)
   CLOSE_AND_RET(_PICERR_NOMEM);
 
 
@@ -200,7 +200,7 @@ for(y=0;y<h;y++)
         case 1:
           do
             if((c=fgetc(in))=='#') ditch_line(in);
-          while(c!='0' && c!='1');
+          while(c!='0' && c!='1' && c!=EOF);
           *ptr++=(c=='1')?0:1;
           break;
         case 2:
@@ -294,6 +294,8 @@ work_closefunc(work_in);
 
 int ditherinit(int w)
 {
+if(WH_BAD(w+10,sizeof(int))) return(0);
+
 ditherfinish();		/* make sure any previous mem is unallocated */
 if((evenerr=calloc(3*(w+10),sizeof(int)))==NULL ||
    (odderr =calloc(3*(w+10),sizeof(int)))==NULL ||
@@ -418,7 +420,7 @@ if(w==0 || h==0 || w>80 || h>60)
 if((maxval=read_next_number(in))!=255)
   return(_PICERR_CORRUPT);
 
-if((*bmap=malloc(w*h))==NULL)
+if(WH_BAD(w,h) || (*bmap=malloc(w*h))==NULL)
   return(_PICERR_NOMEM);
 
 count=fread(*bmap,1,w*h,in);
