@@ -179,7 +179,7 @@ if(bytepp==3 && (*output_type==1 || cfg.jpeg24bit==0))	/* dither? */
  * 3 times as much for each line, which works out only meaning
  * 3x as much for the last line. If you see what I mean. (!?)
  */
-if((*bmap=malloc(w*(h+2)*bytepp))==NULL)
+if(WH_BAD(w,h) || (*bmap=malloc(w*(h+2)*bytepp))==NULL)
   CLOSE_AND_RET(_PICERR_NOMEM);
 
 
