@@ -180,7 +180,7 @@ if(rgb_db_array==NULL)
 if(colchars!=NULL) free(colchars);
 
 /* alloc colchars array */
-if((colchars=malloc(ncols*sizeof(struct colchars_tag)))==NULL)
+if(ncols>(1<<24) || (colchars=malloc(ncols*sizeof(struct colchars_tag)))==NULL)
   CLOSE_AND_RET(_PICERR_NOMEM);
 
 
@@ -369,7 +369,7 @@ switch(cpp)
  */
 
 /* extra lines are in case we're dithering. */
-if((*bmap=malloc(w*(h+2)*bytepp))==NULL)
+if(WH_BAD(w,h) || (*bmap=malloc(w*(h+2)*bytepp))==NULL)
   CLOSE_AND_RET(_PICERR_NOMEM);
 
 ptr=*bmap;
