@@ -9,7 +9,7 @@
  */
 
 #include <stdio.h>
-#include <vga.h>
+#include "zgv_io.h"
 #include "3deffects.h"
 #include "zgv.h"
 #include "scrollbar.h"
