@@ -12,10 +12,10 @@ extern int scrollbar_slider_width(void);
 extern int scrollbar_conv_drag_to_curent(int mx,int dirsiz);
 
 /* defines for the overall bar (including the arrows either end) */
-#define SCRLBAR_XPOS		10
-#define SCRLBAR_YPOS		(vga_getydim()-19)
+#define SCRLBAR_XPOS		5
+#define SCRLBAR_WIDTH		(vga_getxdim()-10)
+#define SCRLBAR_YPOS		(vga_getydim()-16-5)
 #define SCRLBAR_HEIGHT		16
-#define SCRLBAR_WIDTH		(vga_getxdim()-20)
 
 /* defines for both arrows */
 #define SCRLBAR_ARROW_WIDTH	SCRLBAR_HEIGHT
