@@ -1,5 +1,5 @@
-/* zgv 5.7 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-2003 Russell Marks. See README for license details.
+/* zgv 5.9 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2005 Russell Marks. See README for license details.
  *
  * vgadisp.c - VGA-specific display routines.
  */
@@ -178,7 +178,6 @@ unsigned char pal32_no_bc[768];
 unsigned char dither16_greylookup[256];
 unsigned char dither16_rgb[768];
 
-volatile int repeat_sig;
 int first_repeat;
 int loading_file_type;
 int saved_px,saved_py;		/* for persistance in cfg.repeat_timer mode */
@@ -263,7 +262,6 @@ int showgif(char *filename,byte *palette);
 static void draw_rb_menu(void);
 static void undraw_rb_menu(void);
 static int rb_menu_event(int *keyp);
-void repeat_sighandler(int foo);
 void setpalvec(int start,int num,int *pal);
 void redrawgif(int px, int py, int npx, int npy);
 void eventuallydrawscansegment_without_bc(byte *ptr, int x, int y, int len);
@@ -1072,6 +1070,7 @@ int npx=0,npy=0;    /* equivalent to px,py in scaling>1 mode */
 int f;
 int mode_prefix=0;
 int rb_menu_mode=0,scrolling_with_mouse=0;
+int mx=0,my=0,cx=0,cy=0,dx,dy;		/* mouse scroll saved/center/delta */
 int slideshow_pause=0;
 static int orient_lastpicexit_state=0;	/* last picture orientation state */
 int orient_current_state;		/* current picture orientation state */
@@ -1084,6 +1083,7 @@ wait_for_foreground();
  * or (more usually) from selector).
  */
 save_mouse_pos();
+if(has_mouse) mx=mouse_getx(),my=mouse_gety();
 
 orient_current_state=0;		/* picture starts off at normal orientation */
 
@@ -1120,23 +1120,14 @@ if(pixelsize==1)
   init_vkludge_cache();
 
 pic_incr=0;
-repeat_sig=0;
+zgv_io_timer_flag=0;
+if(cfg.repeat_timer<0)
+  cfg.repeat_timer=0;
 if(cfg.repeat_timer && !tagview_mode)
-  {
-  if(cfg.repeat_timer==-1)
-    repeat_sig=2;	/* make it look (nearly) instant */
-  else
-    {
-    signal(SIGALRM,repeat_sighandler);
-    alarm(cfg.repeat_timer);
-    }
-  }
+  zgv_io_timer_start(100*cfg.repeat_timer);
 
 if(tagview_mode)
-  {
-  signal(SIGALRM,repeat_sighandler);
-  alarm(cfg.tag_timer);
-  }
+  zgv_io_timer_start(100*cfg.tag_timer);
 
 quitshow=0;
 filterpal(palette);
@@ -1180,7 +1171,7 @@ if(cfg.auto_animate && gif_delaycount>=2 && pixelsize==1)
 else
   redrawgif(px,py,npx,npy);
 
-while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
+while(!quitshow && (zgv_io_timer_flag!=1 || rb_menu_mode || slideshow_pause))
   {
   if(doing_auto_animate)
     key='e',quitshow=1;		/* do animation only, then exit */
@@ -1224,8 +1215,6 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
     
     /* but mouse dealt with by this. if not clicked an entry, skip
      * rest of loop.
-     * (no repeat_sig==2 handling required here, as even in incredibly
-     * pathological circumstances we *can't* get here with repeat_sig==2.)
      */
     if(rb_menu_event(&key))	/* returns non-zero if should stay in menu */
       continue;
@@ -1233,6 +1222,8 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
     /* otherwise restore saved area of screen, and do action in (faked) key */
     rb_menu_mode=0;
     undraw_rb_menu();
+    mx=mouse_getx();
+    my=mouse_gety();
     goto parsekey;	/* skip normal mouse stuff just in case */
     }
   
@@ -1249,63 +1240,82 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
       /* only allow it if >=480 pixels high! */
       if(scrnhigh>=480)
         {
-        rb_menu_mode=1; scrolling_with_mouse=0;
+        rb_menu_mode=1;
+	if(scrolling_with_mouse)
+	  {
+	  mouse_setposition(mx,my);
+	  scrolling_with_mouse=0;
+	  }
         draw_rb_menu();
         /* if left mouse button down, ignore first end-left-click. */
         rb_ignore_first_left_click=((mbuttons&MOUSE_LEFTBUTTON)?1:0);
         
-        /* skip rest of main loop except this - we still might have to
-         * sort this out (hugely unlikely, but all the same...)
-         */
-        if(repeat_sig==2) repeat_sig--;
+        /* skip rest of main loop except this. */
         continue;
         }
       }
-    
+
     if(scrolling_with_mouse)
       {
-      /* mouse is in sensible range/location for image scroll, then;
-       * read the mouse position into px/py.
+      /* there may be subpixel motion in the low resolution modes,
+       * especially if combined with another event(s), so the mouse
+       * should be recentered on real position changes only.
        */
-      px=mouse_getx();
-      py=mouse_gety();
+      dx=cx-mouse_getx();
+      dy=cy-mouse_gety();
+      if(dx || dy)
+        {
+        px-=dx;
+        py-=dy;
+        mouse_setposition(cx,cy);
+	}
       }
-    
-    /* if left mouse button pressed, or currently scrolling w/mouse,
-     * prepare for next event's movement.
-     * (a bit nasty doing this every time, but we have to, really.)
-     */
-    if((mleft_start || scrolling_with_mouse) && !allow_zoom())
+    else
       {
-      int max_x,max_y;
-      
-      scrolling_with_mouse=1;
-      max_x=width*scaling-scrnwide-1;
-      max_y=height*scaling-scrnhigh-1;
-      /* make sure we don't give it crazy ranges, esp. not 0..0,
-       * which would probably cause a div by zero or something...
+      /* if left mouse button pressed, handle this event's movement
+       * and prepare for next event(s).
        */
-      if(max_x<=0) max_x=1;
-      if(max_y<=0) max_y=1;
-      
-      mouse_setxrange(0,max_x);
-      mouse_setyrange(0,max_y);
-      mouse_setposition(px,py);
+      if(mleft_start && !allow_zoom())
+        {
+        scrolling_with_mouse=1;
+        px+=mx-mouse_getx();
+        py+=my-mouse_gety();
+        mx=mouse_getx();
+        my=mouse_gety();
+        cx=scrnwide/2;
+        cy=scrnhigh/2;
+        mouse_setposition(cx,cy);
+        }
       }
-    
+
     /* if left button not down, don't move with mouse any more.
      * this is after the rest to make sure we don't miss any
      * scrolling motions if scrolling_with_mouse is currently set.
      */
     if(!(mbuttons&MOUSE_LEFTBUTTON))
-      scrolling_with_mouse=0;
-    
+      {
+      if(scrolling_with_mouse)
+        {
+        mouse_setposition(mx,my);
+        scrolling_with_mouse=0;
+        }
+      else
+        {
+        mx=mouse_getx();
+        my=mouse_gety();
+        }
+      }
+
     mleft=0;	/* kludge to keep gcc -Wall happy */
     }
   
   parsekey:
   /* avoid problems with mode or scaling change etc. */
-  if(key) scrolling_with_mouse=0;
+  if(key && scrolling_with_mouse)
+    {
+    mouse_setposition(mx,my);
+    scrolling_with_mouse=0;
+    }
   
   /* mode selection - note that F11=shift-F1 and F12=shift-F2 */
   if(key=='0' || key=='^' || (key>='5' && key<='8') ||
@@ -1372,6 +1382,10 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
         mode_prefix=1;
         break;
       case 'F':
+        cfg.dither_hicol=!cfg.dither_hicol;
+        redraw=1;
+        break;
+      case 'G':
         cfg.fakecols=!cfg.fakecols;
         if(pixelsize==1)
           {
@@ -1384,7 +1398,7 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
         break;
       
       /* the way pause/resume slideshow works is quite simple -
-       * pausing overrides the repeat_sig var set when the timer
+       * pausing overrides the zgv_io_timer_flag var set when the timer
        * times out, and resuming disables that override.
        */
       case 'S'-0x40:	/* pause slideshow */
@@ -1499,12 +1513,12 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
         int ret;
         
         if(cfg.repeat_timer || tagview_mode)
-          alarm(0);		/* cancel timeout for this image */
+          zgv_io_timer_stop();		/* cancel timeout for this image */
         
         ret=animate_gif(orient_current_state);
 
         if(cfg.repeat_timer || tagview_mode)
-          repeat_sig=0;			/* clear it in case */
+          zgv_io_timer_flag=0;			/* clear it in case */
         
         if(doing_auto_animate)	/* no need for redraw */
           {
@@ -1668,8 +1682,6 @@ while(!quitshow && (repeat_sig!=1 || rb_menu_mode || slideshow_pause))
     vkcache_reinit=0;
     redrawgif(px,py,npx,npy);
     }
-  
-  if(repeat_sig==2) repeat_sig--;
   }
 
 graphicsoff();
@@ -1682,7 +1694,7 @@ if(cfg.selecting)
 
 if(cfg.repeat_timer || tagview_mode)
   {
-  alarm(0);
+  zgv_io_timer_stop();
   saved_px=px;
   saved_py=py;
   if(quitshow==1) tagview_mode=0;
@@ -1888,12 +1900,6 @@ return((key==0));	/* 1 if didn't match any, else 0 */
 
 
 
-void repeat_sighandler(int foo)
-{
-repeat_sig=1;
-}
-
-
 void setpalvec(int start,int num,int *pal)
 {
 /* only relevant for 8-bit modes */
@@ -1995,7 +2001,7 @@ else
     int wp=width*pixelsize,sci=scaling*inextpix;
     int scaleincr=0,subpix_xpos,subpix_ypos,sxmulsiz,symulsiz,simulsiz=0;
     int sisize=0,sis2=0;
-    unsigned char *ptr1,*ptr2,*ptr3,*ptr4;
+    unsigned char *ptr1,*ptr2,*ptr3,*ptr4,*ptr2_end,*ptr4_end;
     unsigned char *src,*dst;
     
     if((realline=calloc(pixelsize,scrnwide))==NULL) return;
@@ -2048,10 +2054,12 @@ else
           
           ptr1=ptr3=src+(px/scaling)*3;
           ptr2=ptr4=ptr1+in_rg;
+          ptr2_end=ptr4_end=src+in_dn-3;
           if(pyy<sheight-sci)
             {
             ptr3=ptr1+in_dn;
             ptr4=ptr1+in_dr;
+            ptr4_end+=in_dn;
             }
           
           symulsiz=sisize*subpix_ypos;
@@ -2072,13 +2080,11 @@ else
             if(subpix_xpos>=sisize)
               {
               subpix_xpos=sxmulsiz=0;
-              ptr1+=3; ptr2+=3; ptr3+=3; ptr4+=3;
-              }
-
-            if(pxx>=swidth-sci)
-              {
-              ptr2-=3;
-              ptr4-=3;
+              ptr1+=3; ptr3+=3;
+              if(ptr2<ptr2_end)
+                ptr2+=3;
+              if(ptr4<ptr4_end)
+                ptr4+=3;
               }
             }
           }
@@ -2146,6 +2152,69 @@ else
 }
 
 
+static int inline get15bitcolour_dithered(int x,int y,int r,int g,int b)
+{
+/* ordered dither, based on that used for 16-colour mode */
+static unsigned char ditherdata[12]=
+  {
+  /* red */
+  2,6,
+  8,4,
+  
+  /* green - mirrored */
+  6,2,
+  4,8,
+  
+  /* blue - flipped */
+  8,4,
+  2,6,
+  };
+
+unsigned char *dithptr=ditherdata+(y&1)*2+(x&1);
+int br,bg,bb;
+  
+br=(r&~7)+8*((r&7)>=*dithptr);
+bg=(g&~7)+8*((g&7)>=dithptr[4]);
+bb=(b&~7)+8*((b&7)>=dithptr[8]);
+if(br>255) br=255;
+if(bg>255) bg=255;
+if(bb>255) bb=255;
+
+return(GET15BITCOLOUR(br,bg,bb));
+}
+
+
+static int inline get16bitcolour_dithered(int x,int y,int r,int g,int b)
+{
+/* ordered dither, based on that used for 16-colour mode */
+static unsigned char ditherdata[12]=
+  {
+  /* red */
+  2,6,
+  8,4,
+  
+  /* green - mirrored */
+  3,1,
+  2,4,
+  
+  /* blue - flipped */
+  8,4,
+  2,6,
+  };
+
+unsigned char *dithptr=ditherdata+(y&1)*2+(x&1);
+int br,bg,bb;
+  
+br=(r&~7)+8*((r&7)>=*dithptr);
+bg=(g&~3)+4*((g&3)>=dithptr[4]);
+bb=(b&~7)+8*((b&7)>=dithptr[8]);
+if(br>255) br=255;
+if(bg>255) bg=255;
+if(bb>255) bb=255;
+
+return(GET16BITCOLOUR(br,bg,bb));
+}
+
 
 #define MODE_WIDTH_BUF_SIZE	16384
 
@@ -2176,13 +2245,26 @@ switch(scrnpixelsize)
     {
     unsigned short *bufref=buf;
     unsigned char *ptrend=ptr+len;
+    int xx;
     
     if(scrncols==32768)
-      for(;ptr<ptrend;ptr+=3)
-        *bufref++=GET15BITCOLOUR(ptr[2],ptr[1],*ptr);
+      {
+      if(cfg.dither_hicol)
+        for(xx=x;ptr<ptrend;ptr+=3,xx++)
+          *bufref++=get15bitcolour_dithered(xx,y,ptr[2],ptr[1],*ptr);
+      else
+        for(;ptr<ptrend;ptr+=3)
+          *bufref++=GET15BITCOLOUR(ptr[2],ptr[1],*ptr);
+      }
     else
-      for(;ptr<ptrend;ptr+=3)
-        *bufref++=GET16BITCOLOUR(ptr[2],ptr[1],*ptr);
+      {
+      if(cfg.dither_hicol)
+        for(xx=x;ptr<ptrend;ptr+=3,xx++)
+          *bufref++=get16bitcolour_dithered(xx,y,ptr[2],ptr[1],*ptr);
+      else
+        for(;ptr<ptrend;ptr+=3)
+          *bufref++=GET16BITCOLOUR(ptr[2],ptr[1],*ptr);
+      }
     
     gl_putbox(x,y,bufref-buf,1,buf);
     }
@@ -2232,13 +2314,26 @@ switch(scrnpixelsize)
   case 2:	/* 15/16-bit */
     {
     unsigned short *bufref=buf;
+    int xx;
     
     if(scrncols==32768)
-      for(;ptr<ptrend;ptr+=3)
-        *bufref++=GET15BITCOLOUR(palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      {
+      if(cfg.dither_hicol)
+        for(xx=x;ptr<ptrend;ptr+=3,xx++)
+          *bufref++=get15bitcolour_dithered(xx,y,palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      else
+        for(;ptr<ptrend;ptr+=3)
+          *bufref++=GET15BITCOLOUR(palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      }
     else
-      for(;ptr<ptrend;ptr+=3)
-        *bufref++=GET16BITCOLOUR(palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      {
+      if(cfg.dither_hicol)
+        for(xx=x;ptr<ptrend;ptr+=3,xx++)
+          *bufref++=get16bitcolour_dithered(xx,y,palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      else
+        for(;ptr<ptrend;ptr+=3)
+          *bufref++=GET16BITCOLOUR(palt[ptr[2]],palt[ptr[1]],palt[*ptr]);
+      }
     
     gl_putbox(x,y,bufref-buf,1,buf);
     break;
@@ -2291,23 +2386,24 @@ else
     static unsigned char ditherdata[48]=
       {
       /* red */
-       1*4-2,13*4-2, 4*4-2,16*4-2,
-       9*4-2, 5*4-2,12*4-2, 8*4-2,
-       3*4-2,15*4-2, 2*4-2,14*4-2,
-       7*4-2,10*4-2, 6*4-2,11*4-2,
-       
+      1*4-2,13*4-2, 4*4-2,16*4-2,
+      9*4-2, 5*4-2,12*4-2, 8*4-2,
+      3*4-2,15*4-2, 2*4-2,14*4-2,
+      7*4-2,10*4-2, 6*4-2,11*4-2,
+  
       /* green - mirrored */
       16*4-2, 4*4-2,13*4-2, 1*4-2,
        8*4-2,12*4-2, 5*4-2, 9*4-2,
       14*4-2, 2*4-2,15*4-2, 3*4-2,
       11*4-2, 6*4-2,10*4-2, 7*4-2,
-      
+  
       /* blue - flipped */
-       7*4-2,10*4-2, 6*4-2,11*4-2,
-       3*4-2,15*4-2, 2*4-2,14*4-2,
-       9*4-2, 5*4-2,12*4-2, 8*4-2,
-       1*4-2,13*4-2, 4*4-2,16*4-2
+      7*4-2,10*4-2, 6*4-2,11*4-2,
+      3*4-2,15*4-2, 2*4-2,14*4-2,
+      9*4-2, 5*4-2,12*4-2, 8*4-2,
+      1*4-2,13*4-2, 4*4-2,16*4-2
       };
+    
     unsigned char *dithptr=ditherdata+(y&3)*4+(x&3);
     unsigned char *palptr;
     int xm=4-(x&3);
@@ -2837,7 +2933,6 @@ int paused=0;
 int done=0;
 unsigned char *oldimage;
 unsigned char *dupimage=NULL;
-struct itimerval itv;
 int num_images=gif_delaycount;
 int movetype;
 int offset,startoffset;
@@ -2912,15 +3007,9 @@ while(!done)
 
   theimage=oldimage; width=oldwidth; height=oldheight;
 
-  repeat_sig=0;
-  signal(SIGALRM,repeat_sighandler);
-  
-  itv.it_value.tv_sec=delay/100;
-  itv.it_value.tv_usec=(delay%100)*10000;
-  itv.it_interval.tv_sec=itv.it_interval.tv_usec=0;
-  setitimer(ITIMER_REAL,&itv,NULL);
+  zgv_io_timer_start(delay);
 
-  while(!done && (!repeat_sig || paused))
+  while(!done && (!zgv_io_timer_flag || paused))
     {
     key=wait_for_keys_or_mouse(zgv_ttyfd);
     
@@ -2943,22 +3032,20 @@ while(!done)
 
     if(key=='n')
       {
-      itv.it_value.tv_sec=itv.it_value.tv_usec=0;
-      itv.it_interval.tv_sec=itv.it_interval.tv_usec=0;
-      setitimer(ITIMER_REAL,&itv,NULL);
+      zgv_io_timer_stop();
       break;		/* hence not in the switch() below */
       }
     
     switch(key)
       {
       case 'p':		paused=!paused; break;
-      case RK_ESC:	done=1; break;			/* exit */
+      case RK_ESC: case 'x': done=1; break;		/* exit */
       case RK_ENTER:	done=1; ret=1; break;		/* next image */
       case ' ':		done=1; ret=2; break;		/* tag & next */
       case 127: case 8:	done=1; ret=-1; break;		/* prev image */
       }
     }
-
+  
   hundredths+=delay;
   if(tagtimeout && hundredths>=tagtimeout)
     done=1,ret=1;
@@ -2975,14 +3062,10 @@ while(!done)
 
 override_zoom_clear=0;
 
-itv.it_value.tv_sec=itv.it_value.tv_usec=0;
-itv.it_interval.tv_sec=itv.it_interval.tv_usec=0;
-setitimer(ITIMER_REAL,&itv,NULL);
+zgv_io_timer_stop();
 
 if(dupimage)
   free(dupimage);
 
-repeat_sig=0;
-
 return(ret);
 }
