@@ -1,10 +1,17 @@
-/* zgv 5.7 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
- * Copyright (C) 1993-2003 Russell Marks. See README for license details.
+/* zgv 5.9 - GIF, JPEG and PBM/PGM/PPM viewer, for VGA PCs running Linux.
+ * Copyright (C) 1993-2005 Russell Marks. See README for license details.
  *
  * zgv.h - constants, typedefs.
  */
 
-#define ZGV_VER		"5.7"
+#define ZGV_VER		"5.9"
+
+
+#ifdef __FreeBSD__
+#define OSTYPE_FREEBSD	1
+#else
+#define OSTYPE_LINUX	1
+#endif
 
 
 #define _PIC_OK			 0
@@ -59,3 +66,12 @@ extern void wait_for_foreground(void);
 /* make 15/16-bit colours, used in a few different places */
 #define GET15BITCOLOUR(r,g,b) ((((r)&0xf8)<<7)|(((g)&0xf8)<<2)|((b)>>3))
 #define GET16BITCOLOUR(r,g,b) ((((r)&0xf8)<<8)|(((g)&0xfc)<<3)|((b)>>3))
+
+/* range check on width and height as a crude way of avoiding overflows
+ * when calling malloc/calloc. The maximum we can allow is around 37000,
+ * but 32767 at least makes it consistent with xzgv. :-)
+ * Adds an extra 2 to height for max-height check, as we usually allocate
+ * 2 more lines to allow for dithering.
+ */
+#define WH_MAX	32767
+#define WH_BAD(w,h)	((w)<=0 || (w)>WH_MAX || (h)<=0 || ((h)+2)>WH_MAX)
